fake library
The Fake class for faking dependencies.
This is a re-export of package:test_api/fake.dart. It is kept separate
to avoid a breaking change for users who import package:mockito directly.
Classes
- Fake
- A stand-in for another object which cannot be used except for specifically overridden methods.